pub enum AddressError {
InvalidFormat,
WrongLength(usize),
Decode(Error),
}Expand description
Errors you can get while trying to decode an address.
Variants
InvalidFormat
The address was encoded as bech32, rather than bech32m.
WrongLength(usize)
The data was not 32 bytes in length.
Decode(Error)
An error occured while trying to decode the address.