pub enum PuzzleHashError {
WrongLength(usize),
Decode(FromHexError),
}Expand description
Errors you can get while trying to decode a puzzle hash.
Variants
WrongLength(usize)
The buffer was not 32 bytes in length.
Decode(FromHexError)
An error occured while trying to decode the puzzle hash.